<?php

// checks if a topic is premium
function rcp_topic_is_premium( $topic_id = null ) {

	if ( is_null( $topic_id ) ) {
		$topic_id = bbp_get_topic_id();
	}
	return get_post_meta( $topic_id, '_is_topic_paid', true ) ? true : false;
}

// hides all topics in a restricted forum for non active users
function rcp_filter_topics_list( $query ) {

	global $user_ID;

	if ( bbp_is_single_forum() ) {
		if ( rcp_forum_is_premium( bbp_get_forum_id() ) && ( ! rcp_is_active( $user_ID ) && ! current_user_can( 'moderate' ) ) ) {
			return array(); // return an empty query
		}

		// hide premium topics from inactive users
		if ( rcp_forum_is_premium() && ( ! rcp_is_active( $user_ID ) && ! current_user_can( 'moderate' ) ) ) {
			// get each premium topic
			$excluded_ids = rcp_get_premium_topics( bbp_get_forum_id() );
			$query['post__not_in'] = $excluded_ids;
		}
	}

	return $query;
}
add_filter( 'bbp_has_topics_query', 'rcp_filter_topics_list' );

// retrieves array of all premium topics for the specified forum ID (if given, all otherwise)
function rcp_get_premium_topics( $forum_id = null ) {

	if ( is_null( $forum_id ) ) {
		$forum_id = bbp_get_forum_id();
	}

	$paid_ids = array();
	if ( $forum_id )
		$paid_posts = get_posts( 'meta_key=_is_topic_paid&meta_value=1&post_status=publish&post_type=topic' );
	else
		$paid_posts = get_posts( 'meta_key=_is_topic_paid&meta_value=1&post_status=publish&post_type=topic&post_parent=' . $forum_id );

	if ( $paid_posts ) {
		foreach ( $paid_posts as $p ) {
			$paid_ids[] = $p->ID;
		}
	}
	if ( sizeof( $paid_ids ) >= 1 )
		return $paid_ids;
	return false;
}

// hides the new reply form
function rcp_hide_new_topic_form( $can_access ) {
	global $user_ID;

	if ( rcp_forum_is_premium( bbp_get_forum_id() ) && ( ! rcp_is_active( $user_ID ) && ! current_user_can( 'moderate' ) ) ) {
		return false;
	}
	return $can_access;
}
add_filter( 'bbp_current_user_can_access_create_topic_form', 'rcp_hide_new_topic_form' );

// Disable single topic views
function rcp_hide_single_topic() {

	$topic_id  = get_the_ID();
	$post_type = get_post_type( $topic_id );

	if( bbp_get_topic_post_type() !== $post_type )
		return;


	if( ! rcp_topic_is_premium( $topic_id ) && ! rcp_forum_is_premium( get_post_field( 'post_parent', $topic_id ) ) )
		return;

	if( rcp_is_active() )
		return;

	$redirect = bbp_get_topic_permalink( bbp_get_reply_topic_id( $topic_id ) );

	wp_redirect( home_url( 'wp-login.php?redirect_to=' . urlencode( $redirect ) ) ); exit;
}
add_action( 'template_redirect', 'rcp_hide_single_topic' );